@@ -3,8 +3,8 @@ function(x) {
 if (missing(x)) messagena("x")
 f <- double(1)
 f.res <- .Fortran("cerfd",
-x=to.double(x),
-f=to.double(f))
+x=as.double(x),
+f=as.double(f))
 list(f=f.res$f)
 }
 
