@@ -4,7 +4,7 @@ if (missing(i)) messagena("i")
 x <- double(1)
 f.res <- .Fortran("machd",
 i=to.integer(i),
-x=to.double(x))
+x=as.double(x))
 list(x=f.res$x)
 }
 
