@@ -5,8 +5,8 @@ if (missing(n)) messagena("n")
 nn <- length(a)
 b <- double(nn)
 f.res <- .Fortran("mtt2d",
-a=to.double(a),
-b=to.double(b),
+a=as.double(a),
+b=as.double(b),
 n=to.integer(n),
 nn=to.integer(nn))
 list(b=f.res$b)
